summaryrefslogtreecommitdiff
path: root/silk/float/silk_energy_FLP.c
diff options
context:
space:
mode:
Diffstat (limited to 'silk/float/silk_energy_FLP.c')
-rw-r--r--silk/float/silk_energy_FLP.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/silk/float/silk_energy_FLP.c b/silk/float/silk_energy_FLP.c
index 2995f314..bb6c7807 100644
--- a/silk/float/silk_energy_FLP.c
+++ b/silk/float/silk_energy_FLP.c
@@ -31,9 +31,9 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#include "silk_SigProc_FLP.h"
/* sum of squares of a SKP_float array, with result as double */
double silk_energy_FLP(
- const SKP_float *data,
+ const silk_float *data,
opus_int dataSize
)
{
@@ -55,6 +55,6 @@ double silk_energy_FLP(
result += data[ i ] * data[ i ];
}
- SKP_assert( result >= 0.0 );
+ silk_assert( result >= 0.0 );
return result;
}
@@ -31,9 +31,9 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#include "silk_SigProc_FLP.h"
-/* sum of squares of a SKP_float array, with result as double */
+/* sum of squares of a silk_float array, with result as double */
double silk_energy_FLP(